/*******************************************************************************
* File Name: Count_PM.c  
* Version 2.30
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Count.h"

static Count_backupStruct Count_backup;


/*******************************************************************************
* Function Name: Count_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Count_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void Count_SaveConfig(void) 
{
    #if (!Count_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC5A */
        #if (CY_PSOC5A)
            Count_backup.CounterUdb = Count_ReadCounter();
            Count_backup.CounterPeriod = Count_ReadPeriod();
            Count_backup.CompareValue = Count_ReadCompare();
            Count_backup.InterruptMaskValue = Count_STATUS_MASK;
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            Count_backup.CounterUdb = Count_ReadCounter();
            Count_backup.InterruptMaskValue = Count_STATUS_MASK;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(!Count_ControlRegRemoved)
            Count_backup.CounterControlRegister = Count_ReadControlRegister();
        #endif /* (!Count_ControlRegRemoved) */
    #endif /* (!Count_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Count_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Count_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Count_RestoreConfig(void) 
{      
    #if (!Count_UsingFixedFunction)     
        /* Restore the UDB non-rentention registers for PSoC5A */
        #if (CY_PSOC5A)
            /* Interrupt State Backup for Critical Region*/
            uint8 Count_interruptState;
        
            Count_WriteCounter(Count_backup.CounterUdb);
            Count_WritePeriod(Count_backup.CounterPeriod);
            Count_WriteCompare(Count_backup.CompareValue);
            /* Enter Critical Region*/
            Count_interruptState = CyEnterCriticalSection();
        
            Count_STATUS_AUX_CTRL |= Count_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(Count_interruptState);
            Count_STATUS_MASK = Count_backup.InterruptMaskValue;
        #endif  /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            Count_WriteCounter(Count_backup.CounterUdb);
            Count_STATUS_MASK = Count_backup.InterruptMaskValue;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(!Count_ControlRegRemoved)
            Count_WriteControlRegister(Count_backup.CounterControlRegister);
        #endif /* (!Count_ControlRegRemoved) */
    #endif /* (!Count_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Count_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Count_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void Count_Sleep(void) 
{
    #if(!Count_ControlRegRemoved)
        /* Save Counter's enable state */
        if(Count_CTRL_ENABLE == (Count_CONTROL & Count_CTRL_ENABLE))
        {
            /* Counter is enabled */
            Count_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            Count_backup.CounterEnableState = 0u;
        }
    #else
        Count_backup.CounterEnableState = 1u;
        if(Count_backup.CounterEnableState != 0u)
        {
            Count_backup.CounterEnableState = 0u;
        }
    #endif /* (!Count_ControlRegRemoved) */
    
    Count_Stop();
    Count_SaveConfig();
}


/*******************************************************************************
* Function Name: Count_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Count_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Count_Wakeup(void) 
{
    Count_RestoreConfig();
    #if(!Count_ControlRegRemoved)
        if(Count_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            Count_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!Count_ControlRegRemoved) */
    
}


/* [] END OF FILE */
