/*******************************************************************************
* File Name: TimeBaseSecnd.c  
* Version 2.30
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "TimeBaseSecnd.h"

uint8 TimeBaseSecnd_initVar = 0u;


/*******************************************************************************
* Function Name: TimeBaseSecnd_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Global variables:
*  TimeBaseSecnd_initVar: Is modified when this function is called for the 
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void TimeBaseSecnd_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(TimeBaseSecnd_initVar == 0u)
    {
        TimeBaseSecnd_Init();
        TimeBaseSecnd_initVar = 1u;
    }
    TimeBaseSecnd_Enable();

}


/*******************************************************************************
* Function Name: TimeBaseSecnd_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  TimeBaseSecnd_Start().
*
* Parameters:  
*  None
*
* Return: 
*  None
*
*******************************************************************************/
void TimeBaseSecnd_Init(void) 
{
    #if (TimeBaseSecnd_UsingFixedFunction || TimeBaseSecnd_UseControl)
        uint8 ctrl;
    #endif /* (TimeBaseSecnd_UsingFixedFunction || TimeBaseSecnd_UseControl) */
    
    #if(!TimeBaseSecnd_UsingFixedFunction) 
        #if(TimeBaseSecnd_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 TimeBaseSecnd_interruptState;
        #endif /* (TimeBaseSecnd_UseStatus) */
    #endif /* (!TimeBaseSecnd_UsingFixedFunction) */
    
    #if (TimeBaseSecnd_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        TimeBaseSecnd_CONTROL |= TimeBaseSecnd_CFG0_MODE;
        #if (TimeBaseSecnd_DeadBand2_4)
            TimeBaseSecnd_CONTROL |= TimeBaseSecnd_CFG0_DB;
        #endif /* (TimeBaseSecnd_DeadBand2_4) */
                
        /* Set the default Compare Mode */
        #if(CY_PSOC5A)
                ctrl = TimeBaseSecnd_CONTROL2 & ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE1_MASK));
                TimeBaseSecnd_CONTROL2 = ctrl | TimeBaseSecnd_DEFAULT_COMPARE1_MODE;
        #endif /* (CY_PSOC5A) */
        #if(CY_PSOC3 || CY_PSOC5LP)
                ctrl = TimeBaseSecnd_CONTROL3 & ((uint8 )(~TimeBaseSecnd_CTRL_CMPMODE1_MASK));
                TimeBaseSecnd_CONTROL3 = ctrl | TimeBaseSecnd_DEFAULT_COMPARE1_MODE;
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        TimeBaseSecnd_RT1 &= ((uint8)(~TimeBaseSecnd_RT1_MASK));
        TimeBaseSecnd_RT1 |= TimeBaseSecnd_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        TimeBaseSecnd_RT1 &= ((uint8)(~TimeBaseSecnd_SYNCDSI_MASK));
        TimeBaseSecnd_RT1 |= TimeBaseSecnd_SYNCDSI_EN;
       
    #elif (TimeBaseSecnd_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = TimeBaseSecnd_CONTROL & ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE2_MASK)) & ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE1_MASK));
        TimeBaseSecnd_CONTROL = ctrl | TimeBaseSecnd_DEFAULT_COMPARE2_MODE | 
                                   TimeBaseSecnd_DEFAULT_COMPARE1_MODE;
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
        
    #if (!TimeBaseSecnd_UsingFixedFunction)
        #if (TimeBaseSecnd_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            TimeBaseSecnd_AUX_CONTROLDP0 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
        #else /* (TimeBaseSecnd_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            TimeBaseSecnd_AUX_CONTROLDP0 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
            TimeBaseSecnd_AUX_CONTROLDP1 |= (TimeBaseSecnd_AUX_CTRL_FIFO0_CLR);
        #endif /* (TimeBaseSecnd_Resolution == 8) */

        TimeBaseSecnd_WriteCounter(TimeBaseSecnd_INIT_PERIOD_VALUE);
    #endif /* (!TimeBaseSecnd_UsingFixedFunction) */
        
    TimeBaseSecnd_WritePeriod(TimeBaseSecnd_INIT_PERIOD_VALUE);

        #if (TimeBaseSecnd_UseOneCompareMode)
            TimeBaseSecnd_WriteCompare(TimeBaseSecnd_INIT_COMPARE_VALUE1);
        #else
            TimeBaseSecnd_WriteCompare1(TimeBaseSecnd_INIT_COMPARE_VALUE1);
            TimeBaseSecnd_WriteCompare2(TimeBaseSecnd_INIT_COMPARE_VALUE2);
        #endif /* (TimeBaseSecnd_UseOneCompareMode) */
        
        #if (TimeBaseSecnd_KillModeMinTime)
            TimeBaseSecnd_WriteKillTime(TimeBaseSecnd_MinimumKillTime);
        #endif /* (TimeBaseSecnd_KillModeMinTime) */
        
        #if (TimeBaseSecnd_DeadBandUsed)
            TimeBaseSecnd_WriteDeadTime(TimeBaseSecnd_INIT_DEAD_TIME);
        #endif /* (TimeBaseSecnd_DeadBandUsed) */

    #if (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction)
        TimeBaseSecnd_SetInterruptMode(TimeBaseSecnd_INIT_INTERRUPTS_MODE);
    #endif /* (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction) */
        
    #if (TimeBaseSecnd_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        TimeBaseSecnd_GLOBAL_ENABLE |= TimeBaseSecnd_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        TimeBaseSecnd_CONTROL2 |= TimeBaseSecnd_CTRL2_IRQ_SEL;
    #else
        #if(TimeBaseSecnd_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            TimeBaseSecnd_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            TimeBaseSecnd_STATUS_AUX_CTRL |= TimeBaseSecnd_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(TimeBaseSecnd_interruptState);
            
            /* Clear the FIFO to enable the TimeBaseSecnd_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            TimeBaseSecnd_ClearFIFO();
        #endif /* (TimeBaseSecnd_UseStatus) */
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimeBaseSecnd_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
*******************************************************************************/
void TimeBaseSecnd_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (TimeBaseSecnd_UsingFixedFunction)
        TimeBaseSecnd_GLOBAL_ENABLE |= TimeBaseSecnd_BLOCK_EN_MASK;
        TimeBaseSecnd_GLOBAL_STBY_ENABLE |= TimeBaseSecnd_BLOCK_STBY_EN_MASK;
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
    
    /* Enable the PWM from the control register  */
    #if (TimeBaseSecnd_UseControl || TimeBaseSecnd_UsingFixedFunction)
        TimeBaseSecnd_CONTROL |= TimeBaseSecnd_CTRL_ENABLE;
    #endif /* (TimeBaseSecnd_UseControl || TimeBaseSecnd_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimeBaseSecnd_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
*******************************************************************************/
void TimeBaseSecnd_Stop(void) 
{
    #if (TimeBaseSecnd_UseControl || TimeBaseSecnd_UsingFixedFunction)
        TimeBaseSecnd_CONTROL &= ((uint8)(~TimeBaseSecnd_CTRL_ENABLE));
    #endif /* (TimeBaseSecnd_UseControl || TimeBaseSecnd_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (TimeBaseSecnd_UsingFixedFunction)
        TimeBaseSecnd_GLOBAL_ENABLE &= ((uint8)(~TimeBaseSecnd_BLOCK_EN_MASK));
        TimeBaseSecnd_GLOBAL_STBY_ENABLE &= ((uint8)(~TimeBaseSecnd_BLOCK_STBY_EN_MASK));
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
}


#if (TimeBaseSecnd_UseOneCompareMode)
	#if (TimeBaseSecnd_CompareMode1SW)


		/*******************************************************************************
		* Function Name: TimeBaseSecnd_SetCompareMode
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm output when in Dither mode,
		*  Center Align Mode or One Output Mode.
		*
		* Parameters:
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return:
		*  None
		*
		*******************************************************************************/
		void TimeBaseSecnd_SetCompareMode(uint8 comparemode) 
		{
		    #if(TimeBaseSecnd_UsingFixedFunction)
            
                #if(0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemodemasked = ((uint8)((uint8)comparemode << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT));
                #else
                    uint8 comparemodemasked = comparemode;
                #endif /* (0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT) */
            
		        #if(CY_PSOC5A)
		            TimeBaseSecnd_CONTROL2 &= ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
		            TimeBaseSecnd_CONTROL2 |= comparemodemasked;  
		        #endif /* (CY_PSOC5A) */
		                
		        #if(CY_PSOC3 || CY_PSOC5LP)
		            TimeBaseSecnd_CONTROL3 &= ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
		            TimeBaseSecnd_CONTROL3 |= comparemodemasked;     
		        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
		                
		    #elif (TimeBaseSecnd_UseControl)
		        
                #if(0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemode1masked = ((uint8)((uint8)comparemode << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)) & 
    		                                    TimeBaseSecnd_CTRL_CMPMODE1_MASK;
                #else
                    uint8 comparemode1masked = comparemode & TimeBaseSecnd_CTRL_CMPMODE1_MASK;                
                #endif /* (0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT) */
                
                #if(0 != TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)                            
    		        uint8 comparemode2masked = ((uint8)((uint8)comparemode << TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)) & 
    		                                   TimeBaseSecnd_CTRL_CMPMODE2_MASK;
                #else
    		        uint8 comparemode2masked = comparemode & TimeBaseSecnd_CTRL_CMPMODE2_MASK;                
                #endif /* (0 != TimeBaseSecnd_CTRL_CMPMODE2_SHIFT) */
                
		        /*Clear existing mode */
		        TimeBaseSecnd_CONTROL &= ((uint8)(~(TimeBaseSecnd_CTRL_CMPMODE1_MASK | TimeBaseSecnd_CTRL_CMPMODE2_MASK))); 
		        TimeBaseSecnd_CONTROL |= (comparemode1masked | comparemode2masked);
		        
		    #else
		        uint8 temp = comparemode;
		    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
		}
	#endif /* TimeBaseSecnd_CompareMode1SW */

#else /* UseOneCompareMode */

	#if (TimeBaseSecnd_CompareMode1SW)


		/*******************************************************************************
		* Function Name: TimeBaseSecnd_SetCompareMode1
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm or pwm1 output
		*
		* Parameters:  
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return: 
		*  None
		*
		*******************************************************************************/
		void TimeBaseSecnd_SetCompareMode1(uint8 comparemode) 
		{
		    #if(0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)
                uint8 comparemodemasked = ((uint8)((uint8)comparemode << TimeBaseSecnd_CTRL_CMPMODE1_SHIFT)) & 
    		                               TimeBaseSecnd_CTRL_CMPMODE1_MASK;
		    #else
                uint8 comparemodemasked = comparemode & TimeBaseSecnd_CTRL_CMPMODE1_MASK;                
            #endif /* (0 != TimeBaseSecnd_CTRL_CMPMODE1_SHIFT) */
                   
		    #if (TimeBaseSecnd_UseControl)
		        TimeBaseSecnd_CONTROL &= ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE1_MASK)); /*Clear existing mode */
		        TimeBaseSecnd_CONTROL |= comparemodemasked;
		    #endif /* (TimeBaseSecnd_UseControl) */
		}
	#endif /* TimeBaseSecnd_CompareMode1SW */

#if (TimeBaseSecnd_CompareMode2SW)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_SetCompareMode2
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the Compare Mode for the pwm or pwm2 output
    *
    * Parameters:  
    *  comparemode:  The new compare mode for the PWM output. Use the compare types
    *                defined in the H file as input arguments.
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_SetCompareMode2(uint8 comparemode) 
    {

        #if(0 != TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)
            uint8 comparemodemasked = ((uint8)((uint8)comparemode << TimeBaseSecnd_CTRL_CMPMODE2_SHIFT)) & 
                                                 TimeBaseSecnd_CTRL_CMPMODE2_MASK;
        #else
            uint8 comparemodemasked = comparemode & TimeBaseSecnd_CTRL_CMPMODE2_MASK;            
        #endif /* (0 != TimeBaseSecnd_CTRL_CMPMODE2_SHIFT) */
        
        #if (TimeBaseSecnd_UseControl)
            TimeBaseSecnd_CONTROL &= ((uint8)(~TimeBaseSecnd_CTRL_CMPMODE2_MASK)); /*Clear existing mode */
            TimeBaseSecnd_CONTROL |= comparemodemasked;
        #endif /* (TimeBaseSecnd_UseControl) */
    }
    #endif /*TimeBaseSecnd_CompareMode2SW */

#endif /* UseOneCompareMode */


#if (!TimeBaseSecnd_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteCounter
    ********************************************************************************
    * 
    * Summary:
    *  This function is used to change the counter value.
    *
    * Parameters:  
    *  counter:  This value may be between 1 and (2^Resolution)-1.   
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_WriteCounter(uint16 counter) \
                                       
    {
        CY_SET_REG16(TimeBaseSecnd_COUNTER_LSB_PTR, counter);
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadCounter
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current value of the counter.  It doesn't matter
    *  if the counter is enabled or running.
    *
    * Parameters:  
    *  None  
    *
    * Return: 
    *  The current value of the counter.
    *
    *******************************************************************************/
    uint16 TimeBaseSecnd_ReadCounter(void) 
    {
        /* Force capture by reading Accumulator */
        /* Must first do a software capture to be able to read the counter */
        /* It is up to the user code to make sure there isn't already captured data in the FIFO */
        (void)TimeBaseSecnd_COUNTERCAP_LSB;
        
        /* Read the data from the FIFO (or capture register for Fixed Function)*/
        return (CY_GET_REG16(TimeBaseSecnd_CAPTURE_LSB_PTR));
    }

        #if (TimeBaseSecnd_UseStatus)


            /*******************************************************************************
            * Function Name: TimeBaseSecnd_ClearFIFO
            ********************************************************************************
            * 
            * Summary:
            *  This function clears all capture data from the capture FIFO
            *
            * Parameters:  
            *  None
            *
            * Return: 
            *  None
            *
            *******************************************************************************/
            void TimeBaseSecnd_ClearFIFO(void) 
            {
                while(0u != (TimeBaseSecnd_ReadStatusRegister() & TimeBaseSecnd_STATUS_FIFONEMPTY))
                {
                    (void)TimeBaseSecnd_ReadCapture();
                }
            }

        #endif /* TimeBaseSecnd_UseStatus */

#endif /* !TimeBaseSecnd_UsingFixedFunction */


/*******************************************************************************
* Function Name: TimeBaseSecnd_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  None
*
*******************************************************************************/
void TimeBaseSecnd_WritePeriod(uint16 period) 
{
    #if(TimeBaseSecnd_UsingFixedFunction)
        CY_SET_REG16(TimeBaseSecnd_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(TimeBaseSecnd_PERIOD_LSB_PTR, period);
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
}

#if (TimeBaseSecnd_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteCompare
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value when the PWM is in Dither
    *  mode. The compare output will reflect the new value on the next UDB clock. 
    *  The compare output will be driven high when the present counter value is 
    *  compared to the compare value based on the compare mode defined in 
    *  Dither Mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    * Side Effects:
    *  This function is only available if the PWM mode parameter is set to
    *  Dither Mode, Center Aligned Mode or One Output Mode
    *
    *******************************************************************************/
    void TimeBaseSecnd_WriteCompare(uint16 compare) \
                                       
    {	
		#if(TimeBaseSecnd_UsingFixedFunction)
			CY_SET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR, (uint16)compare);
		#else
	        CY_SET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR, compare);	
		#endif /* (TimeBaseSecnd_UsingFixedFunction) */
        
        #if (TimeBaseSecnd_PWMMode == TimeBaseSecnd__B_PWM__DITHER)
            #if(TimeBaseSecnd_UsingFixedFunction)
    			CY_SET_REG16(TimeBaseSecnd_COMPARE2_LSB_PTR, (uint16)(compare + 1u));
    		#else
    	        CY_SET_REG16(TimeBaseSecnd_COMPARE2_LSB_PTR, (compare + 1u));	
    		#endif /* (TimeBaseSecnd_UsingFixedFunction) */
        #endif /* (TimeBaseSecnd_PWMMode == TimeBaseSecnd__B_PWM__DITHER) */
    }


#else


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteCompare1
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value.  The compare output will 
    *  reflect the new value on the next UDB clock.  The compare output will be 
    *  driven high when the present counter value is less than or less than or 
    *  equal to the compare register, depending on the mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_WriteCompare1(uint16 compare) \
                                        
    {
        #if(TimeBaseSecnd_UsingFixedFunction)
            CY_SET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR, compare);
        #endif /* (TimeBaseSecnd_UsingFixedFunction) */
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteCompare2
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare value, for compare1 output.  
    *  The compare output will reflect the new value on the next UDB clock.  
    *  The compare output will be driven high when the present counter value is 
    *  less than or less than or equal to the compare register, depending on the 
    *  mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_WriteCompare2(uint16 compare) \
                                        
    {
        #if(TimeBaseSecnd_UsingFixedFunction)
            CY_SET_REG16(TimeBaseSecnd_COMPARE2_LSB_PTR, compare);
        #else
            CY_SET_REG16(TimeBaseSecnd_COMPARE2_LSB_PTR, compare);
        #endif /* (TimeBaseSecnd_UsingFixedFunction) */
    }
#endif /* UseOneCompareMode */

#if (TimeBaseSecnd_DeadBandUsed)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the dead-band counts to the corresponding register
    *
    * Parameters:  
    *  deadtime:  Number of counts for dead time 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_WriteDeadTime(uint8 deadtime) 
    {
        /* If using the Dead Band 1-255 mode then just write the register */
        #if(!TimeBaseSecnd_DeadBand2_4)
            CY_SET_REG8(TimeBaseSecnd_DEADBAND_COUNT_PTR, deadtime);
        #else
            /* Otherwise the data has to be masked and offset */        
            /* Clear existing data */
            TimeBaseSecnd_DEADBAND_COUNT &= ((uint8)(~TimeBaseSecnd_DEADBAND_COUNT_MASK));
            
            /* Set new dead time */
            #if(TimeBaseSecnd_DEADBAND_COUNT_SHIFT)        
                TimeBaseSecnd_DEADBAND_COUNT |= ((uint8)((uint8)deadtime << TimeBaseSecnd_DEADBAND_COUNT_SHIFT)) & 
                                                    TimeBaseSecnd_DEADBAND_COUNT_MASK;
            #else
                TimeBaseSecnd_DEADBAND_COUNT |= deadtime & TimeBaseSecnd_DEADBAND_COUNT_MASK;        
            #endif /* (TimeBaseSecnd_DEADBAND_COUNT_SHIFT) */
        
        #endif /* (!TimeBaseSecnd_DeadBand2_4) */
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function reads the dead-band counts from the corresponding register
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  Dead Band Counts
    *
    *******************************************************************************/
    uint8 TimeBaseSecnd_ReadDeadTime(void) 
    {
        /* If using the Dead Band 1-255 mode then just read the register */
        #if(!TimeBaseSecnd_DeadBand2_4)
            return (CY_GET_REG8(TimeBaseSecnd_DEADBAND_COUNT_PTR));
        #else
        
            /* Otherwise the data has to be masked and offset */
            #if(TimeBaseSecnd_DEADBAND_COUNT_SHIFT)      
                return ((uint8)(((uint8)(TimeBaseSecnd_DEADBAND_COUNT & TimeBaseSecnd_DEADBAND_COUNT_MASK)) >> 
                                                                           TimeBaseSecnd_DEADBAND_COUNT_SHIFT));
            #else
                return (TimeBaseSecnd_DEADBAND_COUNT & TimeBaseSecnd_DEADBAND_COUNT_MASK);
            #endif /* (TimeBaseSecnd_DEADBAND_COUNT_SHIFT) */
        #endif /* (!TimeBaseSecnd_DeadBand2_4) */
    }
#endif /* DeadBandUsed */

#if (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_SetInterruptMode
    ********************************************************************************
    * 
    * Summary:
    *  This function configures the interrupts mask control of theinterrupt 
    *  source status register.
    *
    * Parameters:  
    *  uint8 interruptMode: Bit field containing the interrupt sources enabled 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void TimeBaseSecnd_SetInterruptMode(uint8 interruptMode)  
    {
    	CY_SET_REG8(TimeBaseSecnd_STATUS_MASK_PTR, interruptMode);
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadStatusRegister
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current state of the status register. 
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8 : Current status register value. The status register bits are:
    *  [7:6] : Unused(0)
    *  [5]   : Kill event output
    *  [4]   : FIFO not empty
    *  [3]   : FIFO full
    *  [2]   : Terminal count
    *  [1]   : Compare output 2
    *  [0]   : Compare output 1
    *
    *******************************************************************************/
    uint8 TimeBaseSecnd_ReadStatusRegister(void)   
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(TimeBaseSecnd_STATUS_PTR);
    	return (result);
    }

#endif /* (TimeBaseSecnd_UseStatus || TimeBaseSecnd_UsingFixedFunction) */


#if (TimeBaseSecnd_UseControl)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Returns the current state of the control register. This API is available 
    *  only if the control register is not removed.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  uint8 : Current control register value
    *
    *******************************************************************************/    
    uint8 TimeBaseSecnd_ReadControlRegister(void) 
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(TimeBaseSecnd_CONTROL_PTR);
    	return (result);
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Sets the bit field of the control register. This API is available only if 
    *  the control register is not removed.
    *
    * Parameters:  
    *  uint8 control: Control register bit field, The status register bits are:
    *  [7]   : PWM Enable
    *  [6]   : Reset
    *  [5:3] : Compare Mode2
    *  [2:0] : Compare Mode2
    *
    * Return: 
    *  None
    *
    *******************************************************************************/  
    void TimeBaseSecnd_WriteControlRegister(uint8 control) 
    {
    	CY_SET_REG8(TimeBaseSecnd_CONTROL_PTR, control);
    }
	
#endif /* (TimeBaseSecnd_UseControl) */


#if (!TimeBaseSecnd_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadCapture
    ********************************************************************************
    * 
    * Summary:
    *  Reads the capture value from the capture FIFO.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: The current capture value
    *
    *******************************************************************************/  
    uint16 TimeBaseSecnd_ReadCapture(void)  
    {
    	return (CY_GET_REG16(TimeBaseSecnd_CAPTURE_LSB_PTR));
    }
	
#endif /* (!TimeBaseSecnd_UsingFixedFunction) */


#if (TimeBaseSecnd_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadCompare
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare output when the PWM Mode parameter is 
    *  set to Dither mode, Center Aligned mode, or One Output mode.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value
    *
    *******************************************************************************/  
    uint16 TimeBaseSecnd_ReadCompare(void)  
    {
		#if(TimeBaseSecnd_UsingFixedFunction)
            return ((uint16)CY_GET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR));
        #else
            return (CY_GET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR));
        #endif /* (TimeBaseSecnd_UsingFixedFunction) */
    }

#else


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadCompare1
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare1 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint16 TimeBaseSecnd_ReadCompare1(void) 
    {
		return (CY_GET_REG16(TimeBaseSecnd_COMPARE1_LSB_PTR));
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadCompare2
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare2 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint16 TimeBaseSecnd_ReadCompare2(void)  
    {
		return (CY_GET_REG16(TimeBaseSecnd_COMPARE2_LSB_PTR));
    }

#endif /* (TimeBaseSecnd_UseOneCompareMode) */


/*******************************************************************************
* Function Name: TimeBaseSecnd_ReadPeriod
********************************************************************************
* 
* Summary:
*  Reads the period value used by the PWM hardware.
*
* Parameters:  
*  None
*
* Return: 
*  uint8/16: Period value
*
*******************************************************************************/ 
uint16 TimeBaseSecnd_ReadPeriod(void) 
{
	#if(TimeBaseSecnd_UsingFixedFunction)
        return ((uint16)CY_GET_REG16(TimeBaseSecnd_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG16(TimeBaseSecnd_PERIOD_LSB_PTR));
    #endif /* (TimeBaseSecnd_UsingFixedFunction) */
}

#if ( TimeBaseSecnd_KillModeMinTime)


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_WriteKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Writes the kill time value used by the hardware when the Kill Mode 
    *  is set to Minimum Time.
    *
    * Parameters:  
    *  uint8: Minimum Time kill counts
    *
    * Return: 
    *  None
    *
    *******************************************************************************/ 
    void TimeBaseSecnd_WriteKillTime(uint8 killtime) 
    {
    	CY_SET_REG8(TimeBaseSecnd_KILLMODEMINTIME_PTR, killtime);
    }


    /*******************************************************************************
    * Function Name: TimeBaseSecnd_ReadKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Reads the kill time value used by the hardware when the Kill Mode is set 
    *  to Minimum Time.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8: The current Minimum Time kill counts
    *
    *******************************************************************************/ 
    uint8 TimeBaseSecnd_ReadKillTime(void) 
    {
    	return (CY_GET_REG8(TimeBaseSecnd_KILLMODEMINTIME_PTR));
    }

#endif /* ( TimeBaseSecnd_KillModeMinTime) */

/* [] END OF FILE */
