/*******************************************************************************
* File Name: WidthCtr_PM.c
* Version 2.40
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "WidthCtr.h"
static WidthCtr_backupStruct WidthCtr_backup;


/*******************************************************************************
* Function Name: WidthCtr_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  WidthCtr_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void WidthCtr_SaveConfig(void) 
{
    #if (!WidthCtr_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC5A*/
        #if (CY_PSOC5A)
            WidthCtr_backup.TimerUdb = WidthCtr_ReadCounter();
            WidthCtr_backup.TimerPeriod = WidthCtr_ReadPeriod();
            WidthCtr_backup.InterruptMaskValue = WidthCtr_STATUS_MASK;
            #if (WidthCtr_UsingHWCaptureCounter)
                WidthCtr_backup.TimerCaptureCounter = WidthCtr_ReadCaptureCount();
            #endif /* Backup the UDB non-rentention register capture counter for PSoC5A */
        #endif /* Backup the UDB non-rentention registers for PSoC5A */

        #if (CY_PSOC3 || CY_PSOC5LP)
            WidthCtr_backup.TimerUdb = WidthCtr_ReadCounter();
            WidthCtr_backup.InterruptMaskValue = WidthCtr_STATUS_MASK;
            #if (WidthCtr_UsingHWCaptureCounter)
                WidthCtr_backup.TimerCaptureCounter = WidthCtr_ReadCaptureCount();
            #endif /* Back Up capture counter register  */
        #endif /* Backup non retention registers, interrupt mask and capture counter for PSoC3 or PSoC5LP */

        #if(!WidthCtr_ControlRegRemoved)
            WidthCtr_backup.TimerControlRegister = WidthCtr_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: WidthCtr_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  WidthCtr_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void WidthCtr_RestoreConfig(void) 
{   
    #if (!WidthCtr_UsingFixedFunction)
        /* Restore the UDB non-rentention registers for PSoC5A */
        #if (CY_PSOC5A)
            /* Interrupt State Backup for Critical Region*/
            uint8 WidthCtr_interruptState;

            WidthCtr_WriteCounter(WidthCtr_backup.TimerUdb);
            WidthCtr_WritePeriod(WidthCtr_backup.TimerPeriod);
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            WidthCtr_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            WidthCtr_STATUS_AUX_CTRL |= WidthCtr_STATUS_ACTL_INT_EN_MASK;
            /* Exit Critical Region*/
            CyExitCriticalSection(WidthCtr_interruptState);
            WidthCtr_STATUS_MASK =WidthCtr_backup.InterruptMaskValue;
            #if (WidthCtr_UsingHWCaptureCounter)
                WidthCtr_SetCaptureCount(WidthCtr_backup.TimerCaptureCounter);
            #endif /* Restore the UDB non-rentention register capture counter for PSoC5A */
        #endif /* Restore the UDB non-rentention registers for PSoC5A */

        #if (CY_PSOC3 || CY_PSOC5LP)
            WidthCtr_WriteCounter(WidthCtr_backup.TimerUdb);
            WidthCtr_STATUS_MASK =WidthCtr_backup.InterruptMaskValue;
            #if (WidthCtr_UsingHWCaptureCounter)
                WidthCtr_SetCaptureCount(WidthCtr_backup.TimerCaptureCounter);
            #endif /* Restore Capture counter register*/
        #endif /* Restore up non retention registers, interrupt mask and capture counter for PSoC3 or PSoC5LP */

        #if(!WidthCtr_ControlRegRemoved)
            WidthCtr_WriteControlRegister(WidthCtr_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: WidthCtr_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  WidthCtr_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void WidthCtr_Sleep(void) 
{
    #if(!WidthCtr_ControlRegRemoved)
        /* Save Counter's enable state */
        if(WidthCtr_CTRL_ENABLE == (WidthCtr_CONTROL & WidthCtr_CTRL_ENABLE))
        {
            /* Timer is enabled */
            WidthCtr_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            WidthCtr_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    WidthCtr_Stop();
    WidthCtr_SaveConfig();
}


/*******************************************************************************
* Function Name: WidthCtr_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  WidthCtr_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void WidthCtr_Wakeup(void) 
{
    WidthCtr_RestoreConfig();
    #if(!WidthCtr_ControlRegRemoved)
        if(WidthCtr_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                WidthCtr_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
